@@ -33,6 +33,8 @@ int decode_audio_file(ChromaprintContext *chromaprint_ctx, const char *file_name
 	SwrContext *convert_ctx = NULL;
 #elif defined(HAVE_AVRESAMPLE)
 	AVAudioResampleContext *convert_ctx = NULL;
+#else
+	void *convert_ctx = NULL;
 #endif
 	int max_dst_nb_samples = 0, dst_linsize = 0;
 	uint8_t *dst_data[1] = { NULL };
@@ -109,6 +111,9 @@ int decode_audio_file(ChromaprintContext *chromaprint_ctx, const char *file_name
 			fprintf(stderr, "ERROR: couldn't initialize the audio converter\n");
 			goto done;
 		}
+#else
+		fprintf(stderr, "ERROR: unsupported audio format (please build fpcalc with libswresample)\n");
+		goto done;
 #endif
 	}
 
@@ -155,10 +160,11 @@ int decode_audio_file(ChromaprintContext *chromaprint_ctx, const char *file_name
 						max_dst_nb_samples = frame->nb_samples;
 					}
 #if defined(HAVE_SWRESAMPLE)
-					if (swr_convert(convert_ctx, dst_data, frame->nb_samples, (const uint8_t **)frame->data, frame->nb_samples) < 0) {
+					if (swr_convert(convert_ctx, dst_data, frame->nb_samples, (const uint8_t **)frame->data, frame->nb_samples) < 0)
 #elif defined(HAVE_AVRESAMPLE)
-					if (avresample_convert(convert_ctx, dst_data, 0, frame->nb_samples, (uint8_t **)frame->data, 0, frame->nb_samples) < 0) {
+					if (avresample_convert(convert_ctx, dst_data, 0, frame->nb_samples, (uint8_t **)frame->data, 0, frame->nb_samples) < 0)
 #endif
+					{
 						fprintf(stderr, "ERROR: couldn't convert the audio\n");
 						goto done;
 					}
